This module contains analysis for paper
[Log-normal Stochastic Volatility Model with Quadratic Drift](https://www.worldscientific.com/doi/10.1142/S0219024924500031)
by Artur Sepp and Parviz Rakhmonov

See the description of data and analysis in the paper.

Figures in the paper are generated using unittests in
```python 
article_figures.py
```
https://github.com/ArturSepp/StochVolModels/blob/main/my_papers/logsv_model_wtih_quadratic_drift/article_figures.py

See the description of data and analysis in the paper.
